@@ -59,7 +59,9 @@ ListJob::ListJob(Session *session)
     : Job(*new ListJobPrivate(this, session, i18n("List")))
 {
     Q_D(ListJob);
-    connect(&d->emitPendingsTimer, SIGNAL(timeout()), this, SLOT(emitPendings()));
+    connect(&d->emitPendingsTimer, &QTimer::timeout, this, [d]() {
+        d->emitPendings();
+    });
 }
 
 ListJob::~ListJob()
